WeakInternString

Struct WeakInternString 

pub struct WeakInternString { /* private fields */ }
A weak interned string. Similar to Weak, but references an InternString instead

Implementations

Source

impl WeakInternString

pub fn is_alive(&self) -> bool

Returns true if the string is still alive The string is considered dead if there are no strong references

pub fn as_str<'a>(&'a self) -> Option<&'a str>

Gets the underlying string if it’s still alive

pub fn into_strong(&self) -> Option<InternString>

Converts to a strong reference if the string is still alive