pub struct WeakInternString { /* private fields */ }Expand description
A weak interned string.
Similar to Weak
Implementations
Sourceimpl WeakInternString
impl WeakInternString
Sourcepub fn is_alive(&self) -> bool
pub fn is_alive(&self) -> bool
Returns true if the string is still alive The string is considered dead if there are no strong references
Sourcepub fn into_strong(&self) -> Option<InternString>
pub fn into_strong(&self) -> Option<InternString>
Converts to a strong reference if the string is still alive